This is the code for our NeurIPS 2024 paper *<strong>Uncovering Safety Risks of Large Language Models through Concept Activation Vector</strong>*.

## Disclaimer

This project may lead to attacks on LLMs and is intended for academic research use only. It is prohibited for illegal purposes. The authors have shared the vulnerabilities with OpenAI and Microsoft.
